FileSource

Enum FileSource 

#[non_exhaustive]
pub enum FileSource { Bytes { data: Bytes, }, Base64 { data: String, }, Url { url: Url, }, Reference { reference: ProviderReference, }, Text { text: String, }, Path { path: PathBuf, }, }
Where the bytes of a file part come from.

Compared with the provider-level FileData, applications may also pass base64 text (decoded during conversion) and a local path (read during conversion). Wire format is tagged by type: data (base64 bytes), base64, url, reference, text, path.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Bytes

Inline bytes.

Fields

data: Bytes

The bytes (serialized as standard base64).



Base64

Base64 text, decoded during conversion.

Fields

data: String

Standard-alphabet base64, padding optional, whitespace ignored.



Url

A URL, including data: URLs.

Fields

url: Url

The URL.



Reference

A file previously uploaded to one or more providers.

Fields

reference: ProviderReference

Provider key → provider-specific file id.



Text

An inline text document.

Fields

text: String

The text.



Path

A local file read during conversion.

Fields

path: PathBuf

The path.

Implementations

Source

impl FileSource

pub fn bytes(data: impl Into<Bytes>) -> Self

Inline bytes.

pub fn base64(data: impl Into<String>) -> Self

Base64 text.

pub fn url(url: Url) -> Self

A URL.

pub fn reference(provider: impl Into<String>, id: impl Into<String>) -> Self

A single-provider reference.

pub fn text(text: impl Into<String>) -> Self

An inline text document.

pub fn path(path: impl Into<PathBuf>) -> Self

A local path.

pub fn parse_url(url: &str) -> Result<Self, ParseError>

Parses a URL string into a URL source.

Errors

Returns the parse error when url is not an absolute URL.

pub fn as_bytes(&self) -> Option<&Bytes>

Returns the inline bytes when this is a FileSource::Bytes.

pub fn as_url(&self) -> Option<&Url>

Returns the URL when this is a FileSource::Url.

pub fn as_reference(&self) -> Option<&ProviderReference>

Returns the provider reference when this is a FileSource::Reference.

pub fn is_data_url(&self) -> bool

Returns true for a data: URL.

pub fn data_url(&self) -> Option<Result<DataUrl, InvalidDataContentError>>

Parses the data: URL when this is one.

Errors

Returns InvalidDataContentError when the data URL is malformed.

pub fn decoded_bytes(&self) -> Result<Option<Bytes>, InvalidDataContentError>

Decodes inline content (Bytes or Base64) into bytes.

Returns None for sources that are not inline binary content.

Errors

Returns InvalidDataContentError when base64 text does not decode.