#[non_exhaustive]pub enum Message {
System(SystemMessage),
User(UserMessage),
Assistant(AssistantMessage),
Tool(ToolMessage),
}Expand description
A message in an application conversation, tagged by role.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
System(SystemMessage)
Instructions for the model.
User(UserMessage)
Input from the user.
Assistant(AssistantMessage)
Output from the model.
Tool(ToolMessage)
Tool results and approval responses.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn user_parts(parts: impl IntoIterator<Item = impl Into<UserPart>>) -> Self
pub fn user_parts(parts: impl IntoIterator<Item = impl Into<UserPart>>) -> Self
A user message with parts.
Sourcepub fn assistant_parts(
parts: impl IntoIterator<Item = impl Into<AssistantPart>>,
) -> Self
pub fn assistant_parts( parts: impl IntoIterator<Item = impl Into<AssistantPart>>, ) -> Self
An assistant message with parts.
Sourcepub fn tool(parts: impl IntoIterator<Item = impl Into<ToolPart>>) -> Self
pub fn tool(parts: impl IntoIterator<Item = impl Into<ToolPart>>) -> Self
A tool message.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true when the message carries no content (empty string or
no parts).
Sourcepub fn provider_options(&self) -> Option<&ProviderOptions>
pub fn provider_options(&self) -> Option<&ProviderOptions>
Provider-specific options.
Sourcepub fn with_provider_options(self, options: ProviderOptions) -> Self
pub fn with_provider_options(self, options: ProviderOptions) -> Self
Sets provider-specific options.
Sourcepub fn as_system(&self) -> Option<&SystemMessage>
pub fn as_system(&self) -> Option<&SystemMessage>
Returns the system message when this is one.
Sourcepub fn as_user(&self) -> Option<&UserMessage>
pub fn as_user(&self) -> Option<&UserMessage>
Returns the user message when this is one.
Sourcepub fn as_assistant(&self) -> Option<&AssistantMessage>
pub fn as_assistant(&self) -> Option<&AssistantMessage>
Returns the assistant message when this is one.
Sourcepub fn as_tool(&self) -> Option<&ToolMessage>
pub fn as_tool(&self) -> Option<&ToolMessage>
Returns the tool message when this is one.