UserPart

Enum UserPart 

#[non_exhaustive]
pub enum UserPart { Text(TextPart), Image(ImagePart), File(FilePart), }
A part of a user message.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Text(TextPart)

Text.



Image(ImagePart)

An image; normalized to a file part with a detected media type during conversion.



File(FilePart)

A file with an explicit media type.

Implementations

Source

impl UserPart

pub fn text(text: impl Into<String>) -> Self

A text part.

pub fn image(source: impl Into<FileSource>) -> Self

An image from any source.

pub fn image_bytes(data: impl Into<Bytes>) -> Self

An image from inline bytes.

pub fn image_base64(data: impl Into<String>) -> Self

An image from base64 text.

pub fn image_url(url: Url) -> Self

An image from a URL.

pub fn file( source: impl Into<FileSource>, media_type: impl Into<MediaType>, ) -> Self

A file from any source.

pub fn file_bytes( data: impl Into<Bytes>, media_type: impl Into<MediaType>, ) -> Self

A file from inline bytes.

pub fn file_url(url: Url, media_type: impl Into<MediaType>) -> Self

A file from a URL.

pub fn file_reference( reference: ProviderReference, media_type: impl Into<MediaType>, ) -> Self

A file previously uploaded to providers.

pub fn file_text( text: impl Into<String>, media_type: impl Into<MediaType>, ) -> Self

An inline text document.

pub fn file_path( path: impl Into<PathBuf>, media_type: impl Into<MediaType>, ) -> Self

A file read from a local path during conversion.

pub fn with_filename(self, filename: impl Into<String>) -> Self

Sets the filename on a file part (no effect on other parts).

pub fn with_provider_options(self, options: ProviderOptions) -> Self

Sets provider options.

pub fn as_text(&self) -> Option<&str>

Returns the text of a text part.